.. _api-methods:

Job Methods API
***************

Jobs are the units of work in Toil which are composed into workflows.

.. autoclass:: toil.job.Job
   :members:
   :noindex:

JobDescription
--------------

The class used to store all the information that the Toil Leader ever needs to
know about a Job.

.. autoclass:: toil.job.JobDescription
   :members:
   :noindex:
